@@ -11,7 +11,7 @@ use Moo;
 use namespace::clean;
 
 # Version.
-our $VERSION = 0.05;
+our $VERSION = 0.06;
 
 # Get XML.
 has xml => (
@@ -38,6 +38,8 @@ Map::Tube::Moscow - Interface to the Moscow Metro Map.
  use Map::Tube::Moscow;
  my $obj = Map::Tube::Moscow->new;
  my $routes_ar = $obj->get_all_routes($from, $to);
+ my $line = $obj->get_line_by_id($line_id);
+ my $line = $obj->get_line_by_name($line_name);
  my $lines_ar = $obj->get_lines;
  my $station = $obj->get_node_by_id($station_id);
  my $station = $obj->get_node_by_name($station_name);
@@ -66,6 +68,16 @@ For more information about Moscow Map, click L<here|https://ru.wikipedia.org/wik
  Get all routes from station to station.
  Returns reference to array with Map::Tube::Route objects.
 
+=item C<get_line_by_id($line_id)>
+
+ Get line object defined by id.
+ Returns Map::Tube::Line object.
+
+=item C<get_line_by_name($line_name)>
+
+ Get line object defined by name.
+ Returns Map::Tube::Line object.
+
 =item C<get_lines()>
 
  Get lines in metro map.
@@ -183,6 +195,39 @@ For more information about Moscow Map, click L<here|https://ru.wikipedia.org/wik
 
 =end html
 
+=head1 EXAMPLE4
+
+ # Pragmas.
+ use strict;
+ use warnings;
+
+ # Modules.
+ use Encode qw(encode_utf8);
+ use Map::Tube::Moscow;
+
+ # Object.
+ my $obj = Map::Tube::Moscow->new;
+
+ # Get lines.
+ my $lines_ar = $obj->get_lines;
+
+ # Print out.
+ map { print encode_utf8($_->name)."\n"; } sort @{$lines_ar};
+
+ # Output:
+ # Арбатско-Покровская линия
+ # Бутовская линия
+ # Замоскворецкая линия
+ # Калининско-Солнцевская линия
+ # Калужско-Рижская линия
+ # Каховская линия
+ # Кольцевая линия
+ # Люблинско-Дмитровская линия
+ # Серпуховско-Тимирязевская линия
+ # Сокольническая линия
+ # Таганско-Краснопресненская линия
+ # Филёвская линия
+
 =head1 DEPENDENCIES
 
 L<File::Share>,
@@ -192,41 +237,21 @@ L<namespace::clean>.
 
 =head1 SEE ALSO
 
-L<Map::Tube>,
-L<Map::Tube::Graph>,
-L<Map::Tube::GraphViz>,
-L<Map::Tube::Plugin::FuzzyFind>,
-L<Map::Tube::Plugin::Graph>,
-L<Map::Tube::Text::Table>,
-L<Task::Map::Tube>.
+=over
 
-L<Map::Tube::Barcelona>,
-L<Map::Tube::Berlin>,
-L<Map::Tube::Bucharest>,
-L<Map::Tube::Budapest>,
-L<Map::Tube::Delhi>,
-L<Map::Tube::Dnipropetrovsk>,
-L<Map::Tube::Glasgow>,
-L<Map::Tube::Kazan>,
-L<Map::Tube::Kharkiv>,
-L<Map::Tube::Kiev>,
-L<Map::Tube::KoelnBonn>,
-L<Map::Tube::London>,
-L<Map::Tube::Lyon>,
-L<Map::Tube::Minsk>,
-L<Map::Tube::NYC>,
-L<Map::Tube::Nanjing>,
-L<Map::Tube::Novosibirsk>,
-L<Map::Tube::Prague>,
-L<Map::Tube::SaintPetersburg>,
-L<Map::Tube::Samara>,
-L<Map::Tube::Singapore>,
-L<Map::Tube::Sofia>,
-L<Map::Tube::Tbilisi>,
-L<Map::Tube::Tokyo>,
-L<Map::Tube::Vienna>,
-L<Map::Tube::Warsaw>,
-L<Map::Tube::Yekaterinburg>.
+=item L<Map::Tube>
+
+Core library as Role (Moo) to process map data.
+
+=item L<Task::Map::Tube>
+
+Install the Map::Tube modules.
+
+=item L<Task::Map::Tube::Metro>
+
+Install the Map::Tube concrete metro modules.
+
+=back
 
 =head1 REPOSITORY
 
@@ -246,6 +271,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.05
+0.06
 
 =cut
